@@ -339,7 +339,7 @@ void xdebug_debugger_throw_exception_hook(zval *exception, zval *file, zval *lin
 				Z_STR_P(file), Z_LVAL_P(line), XDEBUG_BREAK,
 				(char*) STR_NAME_VAL(exception_ce->name),
 				code_str ? code_str : ((code && Z_TYPE_P(code) == IS_STRING) ? Z_STRVAL_P(code) : NULL),
-				Z_STRVAL_P(message))
+				message ? Z_STRVAL_P(message) : "")
 			) {
 				xdebug_mark_debug_connection_not_active();
 			}
@@ -782,6 +782,24 @@ PHP_FUNCTION(xdebug_break)
 		RETURN_FALSE;
 	}
 
+	/* Go through every stack frame to register compiled variables */
+	{
+		function_stack_entry *loop_fse = XDEBUG_VECTOR_TAIL(XG_BASE(stack));
+		int                   i;
+
+		for (i = 0; i < XDEBUG_VECTOR_COUNT(XG_BASE(stack)); i++, loop_fse--) {
+			if (loop_fse->declared_vars) {
+				continue;
+			}
+
+			if (loop_fse->user_defined == XDEBUG_BUILT_IN) {
+				continue;
+			}
+
+			xdebug_lib_register_compiled_variables(loop_fse, loop_fse->op_array);
+		}
+	}
+
 	XG_DBG(context).do_break = 1;
 	RETURN_TRUE;
 }
